# Changelog

<!--next-version-placeholder-->

## v0.2.0 (2025-05-08)

### Feature

* Support `high_precision` to extract microsecond (instead of millisecond) timestamp from uuid7 ([`683be36`](https://github.com/educationwarehouse/uuid7/commit/683be36d52e311287bc38eeb23ecbeb79c61a3c2))

## v0.1.1 (2025-05-02)

### Documentation

* Cleaned up changelog, added more info about stateless monotonicity ([`906ac1c`](https://github.com/educationwarehouse/uuid7/commit/906ac1c34c5773b0a00ce3355aaceaa9de5b9b16))

## v0.1.0 (2025-05-02)

### Feature

* Initial implementation of uuid7 with µs resolving for sorting. ([`63d4824`](https://github.com/educationwarehouse/uuid7/commit/63d482401e387ee8bb67761180d1abb63e1e2aca))
